pub enum LayoutFunction {
Packed,
Split,
}Variants
Packed
Standard layout function which maps all fields into a single memory slot / register. This function must be given exactly a single argument
Split
Standard layout function which maps each entry in the variable structure to a distinct register / memory location. Must take N arguments where N is the number of entries for the type.