pub struct VariableName<S>{ /* private fields */ }Expand description
A thin wrapper over a String for names used by the source info table
Implementations
Sourceimpl<S> VariableName<S>
impl<S> VariableName<S>
pub fn new(name: S, name_is_literal: bool) -> VariableName<S>
pub fn new_non_literal(name: S) -> VariableName<S>
pub fn new_literal(name: S) -> VariableName<S>
pub fn into_inner(self) -> S
pub fn as_str(&self) -> &str
Sourcepub fn flip_is_literal(&mut self)
pub fn flip_is_literal(&mut self)
flips the name_is_literal bool. should only be used when searching for a value in a hashmap
pub fn set_is_literal(&mut self)
pub fn unset_is_literal(&mut self)